@@ -57,7 +57,7 @@ class FeedingItHomePlugin(hildondesktop.HomePluginItem):
         self.connect("show-settings", self.show_settings)
         self.feed_list = {}
         self.total = 0
-        self.autoupdateID=False
+        self.autoupdateId=False
         
         vbox = gtk.VBox(False, 0)
         
@@ -301,12 +301,12 @@ class FeedingItHomePlugin(hildondesktop.HomePluginItem):
 
     def setup_autoupdate(self):
         if (float(self.autoupdate) > 0):
-            if (not self.autoupdateID==False):
+            if (not self.autoupdateId==False):
                 gobject.source_remove(self.autoupdateId)
             self.autoupdateId = gobject.timeout_add_seconds(int(float(self.autoupdate)*3600), self.start_update)
         else:
-            if (not self.autoupdateID==False):
-                gobject.disconnect(self.autoupdateId)
+            if (not self.autoupdateId==False):
+                gobject.source_remove(self.autoupdateId)
                 self.autoupdateID=False
 
     def load_config(self):
